@@ -13,7 +13,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
 
-library(naijR)
 
 test_that("illegal input is caught early", {
   expect_error(lgas_ng("Maryland"),
@@ -21,16 +20,21 @@ test_that("illegal input is caught early", {
                fixed = TRUE)
 })
 
+
+
+
+
 test_that("LGAs are returned correctly", {
-  res <- lgas_ng("Imo")
+  res <- lgas_ng("Plateau")
   res2 <- lgas_ng(nam <- c("Borno", "Abia"))
   
-  expect_match(res, "Owerri North", all = FALSE)
-  expect_length(res, 27L)
+  expect_match(res, "Pankshin", all = FALSE)
+  expect_length(res, 17L)
   expect_type(res, "character")
   expect_is(res, "character")
+  expect_null(names(res))
   expect_is(res2, "list")
   expect_type(res2, "list")
-  expect_named(res2, (nam))
-  expect_length(res2, 2)
+  expect_named(res2, nam)
+  expect_length(res2, 2L)
 })
